# CreateBillingAccountRequest

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**display_name** | **str** |  | 
**invoice_name** | **str** |  | [optional] 
**email** | **str** |  | 
**tax_id** | [**TaxId**](TaxId.md) |  | [optional] 
**referral** | **str** |  | [optional] 
**billing_address** | [**BillingAddress**](BillingAddress.md) |  | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


